import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import DeviceBindCreate from "./DeviceBindCreate";
import DeviceBindPanel from "./DeviceBindPanel";
import EmptyData from "../components/EmptyData";
import MyCreateButton from "../components/MyCreateButton";
import MyExportButton from '../components/MyExportButton';
import PageDrawer from "../components/PageDrawer";
import MyField from "../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <DateInput label='common.time.after' source="timeStart" alwaysOn />,
    <DateInput label='common.time.before' source="timeEnd" alwaysOn />,

    <NumberInput source="currentRow" label="table.field.deviceBind.currentRow" />,
    <NumberInput source="startRow" label="table.field.deviceBind.startRow" />,
    <NumberInput source="endRow" label="table.field.deviceBind.endRow" />,
    <NumberInput source="deviceQty" label="table.field.deviceBind.deviceQty" />,
    <NumberInput source="startDeviceNo" label="table.field.deviceBind.startDeviceNo" />,
    <NumberInput source="endDeviceNo" label="table.field.deviceBind.endDeviceNo" />,
    <TextInput source="staList" label="table.field.deviceBind.staList" />,
    <NumberInput source="typeId" label="table.field.deviceBind.typeId" />,
    <TextInput source="beSimilar" label="table.field.deviceBind.beSimilar" />,
    <TextInput source="emptySimilar" label="table.field.deviceBind.emptySimilar" />,

    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const DeviceBindList = () => {
    const translate = useTranslate();

    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);

    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: !!drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.deviceBind"}
                empty={<EmptyData onClick={() => { setCreateDialog(true) }} />}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <MyCreateButton onClick={() => { setCreateDialog(true) }} />
                        <SelectColumnsButton preferenceKey='deviceBind' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='deviceBind'
                    bulkActionButtons={() => <BulkDeleteButton mutationMode={OPERATE_MODE} />}
                    rowClick={(id, resource, record) => false}
                    expand={() => <DeviceBindPanel />}
                    expandSingle={true}
                    omit={['id', 'createTime', 'createBy', 'memo']}
                >
                    <NumberField source="id" />
                    <NumberField source="currentRow" label="table.field.deviceBind.currentRow" />
                    <NumberField source="startRow" label="table.field.deviceBind.startRow" />
                    <NumberField source="endRow" label="table.field.deviceBind.endRow" />
                    <NumberField source="deviceQty" label="table.field.deviceBind.deviceQty" />
                    <NumberField source="startDeviceNo" label="table.field.deviceBind.startDeviceNo" />
                    <NumberField source="endDeviceNo" label="table.field.deviceBind.endDeviceNo" />
                    <TextField source="staList" label="table.field.deviceBind.staList" />
                    <ReferenceField source="typeId" label="table.field.deviceBind.typeId" reference="warehouseAreas" link={false} sortable={false}>
                        <TextField source="name" />
                    </ReferenceField>
                    <TextField source="beSimilar" label="table.field.deviceBind.beSimilar" />
                    <TextField source="emptySimilar" label="table.field.deviceBind.emptySimilar" />

                    <ReferenceField source="updateBy" label="common.field.updateBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <ReferenceField source="createBy" label="common.field.createBy" reference="user" link={false} sortable={false}>
                        <TextField source="nickname" />
                    </ReferenceField>
                    <DateField source="createTime" label="common.field.createTime" showTime />
                    <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                    <WrapperField cellClassName="opt" label="common.field.opt">
                        <EditButton sx={{ padding: '1px', fontSize: '.75rem' }} />
                        <DeleteButton sx={{ padding: '1px', fontSize: '.75rem' }} mutationMode={OPERATE_MODE} />
                    </WrapperField>
                </StyledDatagrid>
            </List>
            <DeviceBindCreate
                open={createDialog}
                setOpen={setCreateDialog}
            />
            <PageDrawer
                title='DeviceBind Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default DeviceBindList;
